@@ -897,7 +897,7 @@ def func_FrontFace(mesh):
 def removedup(x):
   return list(dict.fromkeys(x))
 
-def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
+def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, min_num_point_ratio=50, max_num_point_ratio=10, range_random_inc_Z=(20,30), range_random_llZ=(0,1)):
     mesh_pre = mesh.copy()
 
     #danh sách index face sẽ lấy random
@@ -907,8 +907,8 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
             if func_checkY(mesh_pre.vertices,mesh_pre.faces[i], limitY_min, limitY_max):
                 list_index_face.append(i)
     index_Face_begin = np.random.choice(list_index_face)
-    min_num_point = int(len(list_index_face)/50)
-    max_num_point = int(len(list_index_face)/10)
+    min_num_point = int(len(list_index_face)/min_num_point_ratio)
+    max_num_point = int(len(list_index_face)/max_num_point_ratio)
     num_vertices_pick = np.random.randint(min_num_point,max_num_point)
     lst_vertices_picked = []
     lst_vertices_picked.append(mesh_pre.faces[index_Face_begin][0])
@@ -936,15 +936,20 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
         _tmp_ver_pkd.append(_tmp_ver)
 
     # mesh_pre1 = mesh_pre.copy()
-    _inc_Z = np.random.randint(20,30)
-    llZ = np.random.randint(0,1)
+    _inc_Z = np.random.randint(range_random_inc_Z[0], range_random_inc_Z[1])
+    llZ = np.random.randint(range_random_llZ[0],range_random_llZ[1])
     sm = len(_tmp_ver_pkd)
     if llZ == 0:
         _inc_Z = -_inc_Z
-        
+    
+    colors = [ [100,100,100,100] for i in range(len(mesh_pre.vertices))]
+
     for i in range(sm):
         for idx_ver in _tmp_ver_pkd[i]:
             mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
+            colors[idx_ver] = [100,200,10,100]
+
+    mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
 
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
@@ -960,7 +965,7 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
 
 
 # lặp chỗ này để tạo sẹo dài
-def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
+def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max, min_num_point_ratio=200, max_num_point_ratio=20, range_random_inc_Z=(20,30), range_num_ver_c=(10,30), range_random_llZ=(0,1)):
     mesh_pre = mesh.copy()
 
     #danh sách index face sẽ lấy random
@@ -970,8 +975,8 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
             if func_checkY(mesh_pre.vertices,mesh_pre.faces[i], limitY_min, limitY_max):
                 list_index_face.append(i)
     index_Face_begin = np.random.choice(list_index_face)
-    min_num_point = int(len(list_index_face)/200)
-    max_num_point = int(len(list_index_face)/20)
+    min_num_point = int(len(list_index_face)/min_num_point_ratio)
+    max_num_point = int(len(list_index_face)/max_num_point_ratio)
     num_vertices_pick = np.random.randint(min_num_point,max_num_point)
     lst_vertices_picked = []
     lst_vertices_picked.append(mesh_pre.faces[index_Face_begin][0])
@@ -999,7 +1004,7 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
         lst_cood_ver_X = sorted(lst_cood_ver_X, key=take_first)  
 
         # số đỉnh được chọn ngẫu nhiên từ
-        num_ver_c = np.random.randint(10,30)
+        num_ver_c = np.random.randint(range_num_ver_c[0],range_num_ver_c[1])
         bg_get = num_ver_c
         end_get = len(lst_cood_ver_X) - num_ver_c
         if bg_get < end_get:
@@ -1020,16 +1025,20 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
 
         _tmp_ver_pkd.append(_tmp_ver)
 
-    _inc_Z = np.random.randint(20,30)
-    llZ = np.random.randint(0,1)
+    _inc_Z = np.random.randint(range_random_inc_Z[0],range_random_inc_Z[1])
+    llZ = np.random.randint(range_random_llZ[0],range_random_llZ[1])
     sm = len(_tmp_ver_pkd)
     if llZ == 0:
         _inc_Z = -_inc_Z
         
+    colors = [ [100,100,100,100] for i in range(len(mesh_pre.vertices))]
+
     for i in range(sm):
         for idx_ver in _tmp_ver_pkd[i]:
             mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
+            colors[idx_ver] = [100,200,10,100]
 
+    mesh_pre = trimesh.Trimesh(vertices = mesh_pre.vertices, faces = mesh_pre.faces, vertex_colors = colors)
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
 
@@ -1044,7 +1053,11 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
 
 
 
-def scarCreatingV2(mesh, path, numGenScar=10):
+def scarCreatingV2(
+    mesh, path, numGenScar=10, mesh_return=True,
+    circle_scar_min_num_point_ratio=50, circle_scar_max_num_point_ratio=10, circle_scar_range_random_inc_Z=(20,30), circle_scar_range_random_llZ=(0,1),
+    long_scar_min_num_point_ratio=200, long_scar_max_num_point_ratio=20, long_scar_range_random_inc_Z=(20,30), long_scar_range_num_ver_c=(10,30), long_scar_range_random_llZ=(0,1)
+    ):
     """
         scarCreating version 2
     """
@@ -1052,13 +1065,20 @@ def scarCreatingV2(mesh, path, numGenScar=10):
     limitY_min, limitY_max = func_EyeSpace(mesh.vertices)
     
     circleScarMeshList = [
-        circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max)
+        circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max,
+            circle_scar_min_num_point_ratio, circle_scar_max_num_point_ratio, circle_scar_range_random_inc_Z, circle_scar_range_random_llZ
+        )
         for index in range(int(numGenScar/2))
         ]
 
     longScarMeshList = [
-        longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max)
+        longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max,
+            long_scar_min_num_point_ratio, long_scar_max_num_point_ratio, long_scar_range_random_inc_Z, long_scar_range_num_ver_c, long_scar_range_random_llZ
+        )
         for index in range(int(numGenScar/2), numGenScar)
         ]
 
-    return circleScarMeshList, longScarMeshList
\ No newline at end of file
+    if mesh_return == True:
+        return circleScarMeshList, longScarMeshList
+
+    return True
\ No newline at end of file
